@@ -1,7 +1,7 @@
 package Bencher::Scenarios::IPCRun;
 
-our $DATE = '2016-10-13'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.002'; # VERSION
 
 1;
 # ABSTRACT: Scenarios to benchmark IPC::Run
@@ -18,24 +18,14 @@ Bencher::Scenarios::IPCRun - Scenarios to benchmark IPC::Run
 
 =head1 VERSION
 
-This document describes version 0.001 of Bencher::Scenarios::IPCRun (from Perl distribution Bencher-Scenarios-IPCRun), released on 2016-10-13.
-
-=head1 DESCRIPTION
-
-This distribution contains the following L<Bencher> scenario modules:
-
-=over
-
-=item * L<Bencher::Scenario::IPCRun::run_overhead>
-
-=item * L<Bencher::Scenario::IPCRun::run_stdin>
-
-=back
+This document describes version 0.002 of Bencher::Scenarios::IPCRun (from Perl distribution Bencher-Scenarios-IPCRun), released on 2017-01-25.
 
 =head1 TODO
 
 Show where IPC::Run is slow.
 
+run_overhead still sometimes exit.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-IPCRun>.
@@ -60,7 +50,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
